@@ -3,7 +3,7 @@ import networkx as nx
 #from imnet import process_strings as p # info: commented out at 22rd of November 2020
 #from plotData import InnerDataLevenshtein # info: commented out at 22rd of November 2020
 from . import funcDictionary as dic
-import opencl_matrix as om
+from . import opencl_matrix as om
 #from . import opencl_matrixCopy2 as om
 # --------------------------------- PAY ATTENTION: opencl_matrixCopy2 vd opencl_matrix
 
